@@ -4,6 +4,7 @@
 /*
  * Copyright (C) 2003 Ximian, Inc.
  * Authors: Federico Mena-Quintero <federico@ximian.com>
+ * Copyright (C) 2006-2007 Vincent Untz
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -79,11 +80,6 @@ const char * wnck_class_group_get_name (WnckClassGroup *class_group);
 GdkPixbuf *wnck_class_group_get_icon (WnckClassGroup *class_group);
 GdkPixbuf *wnck_class_group_get_mini_icon (WnckClassGroup *class_group);
 
-WnckClassGroup *_wnck_class_group_create (const char *res_class);
-void _wnck_class_group_destroy (WnckClassGroup *class_group);
-void _wnck_class_group_add_window (WnckClassGroup *class_group, WnckWindow *window);
-void _wnck_class_group_remove_window (WnckClassGroup *class_group, WnckWindow *window);
-
 G_END_DECLS
 
 #endif
